==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/GenerationStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GenerationStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.GenerationStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.GenerationStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.GenerationStatus,io.fabric8.openshift.api.model.operator.v1.GenerationStatusBuilder>{
  public GenerationStatusBuilder() {
    this(false);
  }
  public GenerationStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new GenerationStatus(), validationEnabled);
  }
  public GenerationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.GenerationStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public GenerationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.GenerationStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GenerationStatus(), validationEnabled);
  }
  public GenerationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.GenerationStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.GenerationStatus instance) {
    this(fluent, instance, false);
  }
  public GenerationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.GenerationStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.GenerationStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroup(instance.getGroup()); 
    fluent.withHash(instance.getHash()); 
    fluent.withLastGeneration(instance.getLastGeneration()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withResource(instance.getResource()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public GenerationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.GenerationStatus instance) {
    this(instance,false);
  }
  public GenerationStatusBuilder(io.fabric8.openshift.api.model.operator.v1.GenerationStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroup(instance.getGroup()); 
    this.withHash(instance.getHash()); 
    this.withLastGeneration(instance.getLastGeneration()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withResource(instance.getResource()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.GenerationStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.GenerationStatus build() {
    GenerationStatus buildable = new GenerationStatus(fluent.getGroup(),fluent.getHash(),fluent.getLastGeneration(),fluent.getName(),fluent.getNamespace(),fluent.getResource());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GenerationStatusBuilder that = (GenerationStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.5.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/GenerationStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GenerationStatusBuilder extends GenerationStatusFluentImpl<GenerationStatusBuilder> implements VisitableBuilder<GenerationStatus,GenerationStatusBuilder>{
  public GenerationStatusBuilder() {
    this(false);
  }
  public GenerationStatusBuilder(Boolean validationEnabled) {
    this(new GenerationStatus(), validationEnabled);
  }
  public GenerationStatusBuilder(GenerationStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public GenerationStatusBuilder(GenerationStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GenerationStatus(), validationEnabled);
  }
  public GenerationStatusBuilder(GenerationStatusFluent<?> fluent,GenerationStatus instance) {
    this(fluent, instance, false);
  }
  public GenerationStatusBuilder(GenerationStatusFluent<?> fluent,GenerationStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroup(instance.getGroup()); 
    fluent.withHash(instance.getHash()); 
    fluent.withLastGeneration(instance.getLastGeneration()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withResource(instance.getResource()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public GenerationStatusBuilder(GenerationStatus instance) {
    this(instance,false);
  }
  public GenerationStatusBuilder(GenerationStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroup(instance.getGroup()); 
    this.withHash(instance.getHash()); 
    this.withLastGeneration(instance.getLastGeneration()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withResource(instance.getResource()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  GenerationStatusFluent<?> fluent;
  Boolean validationEnabled;
  public GenerationStatus build() {
    GenerationStatus buildable = new GenerationStatus(fluent.getGroup(),fluent.getHash(),fluent.getLastGeneration(),fluent.getName(),fluent.getNamespace(),fluent.getResource());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
